@@ -1,7 +1,7 @@
 """Constants package for PyVSS."""
 PACKAGE_NAME = "pyvss"
 
-__version__ = '2022.8.1'
+__version__ = '2022.9.0'
 
 
 API_ENDPOINT_BASE = 'https://cloud-api.eis.utoronto.ca'
@@ -204,3 +204,14 @@ VALID_VM_FIRMWARE_TYPE = [
     {"description": "BIOS firmware", "type": "bios"},
     {"description": "Extensible Firmware Interface", "type": "efi"},
 ]
+
+VALID_VM_STORAGE_TYPE = [
+    {
+        'description': 'Storage Cluster backed by Solid-State Drives.',
+        'option': 'ssd',
+    },
+    {
+        'description': 'Storage Clusters backed by Hard disk drives.',
+        'option': 'HDD',
+    },
+]
